## 0.15.1 (2026-02-13)

### Feat

- Switch to trusted publishing with OpenID Connect

### Fix

- PYPI config

## 0.14.0 (2026-02-13)

### Feat

- Upgrade sentence-transformers to v5.2.2
- Add auto-publish workflow on merge to main
- Auto-create git tags in publish script

## 0.12.1 (2025-12-24)

## 0.12.0 (2025-12-24)

### Feat

- AI docs, examples, etc

## 0.11.2 (2025-10-21)

### Feat

- Release CI/CD
- Stateless agents
- Multi-Agent setup support
- Supervisor unit testing

### Fix

- Release scripts
- Refactoring: performance and stability improvements
- Linting removed
- Description logger fix
- Multi-agent workflow improvements
- Supervisor export
- Testing pipeline
- Improved topics configuration
- CLI Client export
- CLI Client refactoring
- Tests adjustment
- MQTT connection stability improved
- Tool workflow fixed
- Test fixes
- python action
- Docs pipeline fix
- Github Actions adjusted
- Tests fixed to new structure
- Structure refactoring
- Export structure
- RAG Tool Service no module-lvl config
- RAG service path
- Export file structure
- deleted temp file
- prevent infinite version bump loop and reset to 0.8.4
- always_run for post-commit bump
- dummy test
- Version to post-commit
- Version file config
- dev deps
- Lib upgrade
- Prompt template

## 0.8.3 (2025-07-12)

## 0.8.2 (2025-07-12)

### Fix

- autobumping

## 0.8.1 (2025-07-12)

### Feat

- Test imports upgraded to the new structure

### Fix

- Version

## 0.7.0 (2025-07-12)

### Feat

- Custom system prompt

### Fix

- GitHub release script now filters semantic version tags only
- Github release workflow

## 0.6.0 (2025-05-29)

### Feat

- Argentic as module
- Environment knowledge tool
- Environment store for coordinate-based RAG

### Fix

- reset version to baseline for proper commitizen operation
- Agent shutdown
- CLI client id
- Entry command arguments parsing
- Precommit testing scripts

## 0.15.0 (2026-02-13)

### Feat

- Switch to trusted publishing with OpenID Connect

## 0.14.0 (2026-02-13)

### Feat

- Upgrade sentence-transformers to v5.2.2 for transformers 5.x compatibility

## 0.13.0 (2025-12-25)

### Feat

- Auto-create git tags in publish script

## 0.12.1 (2025-12-24)

## 0.12.0 (2025-12-24)

### Feat

- AI docs, examples, etc

## 0.11.2 (2025-10-21)

### Feat

- Release CI/CD
- Stateless agents
- Multi-Agent setup support
- Supervisor unit testing

### Fix

- Release scripts
- Refactoring: performance and stability improvements
- Linting removed
- Description logger fix
- Multi-agent workflow improvements
- Supervisor export
- Testing pipeline
- Improved topics configuration
- CLI Client export
- CLI Client refactoring
- Tests adjustment
- MQTT connection stability improved
- Tool workflow fixed
- Test fixes
- python action
- Docs pipeline fix
- Github Actions adjusted
- Tests fixed to new structure
- Structure refactoring
- Export structure
- RAG Tool Service no module-lvl config
- RAG service path
- Export file structure
- deleted temp file
- prevent infinite version bump loop and reset to 0.8.4
- always_run for post-commit bump
- dummy test
- Version to post-commit
- Version file config
- dev deps
- Lib upgrade
- Prompt template

## 0.8.3 (2025-07-12)

## 0.8.2 (2025-07-12)

### Fix

- autobumping

## 0.8.1 (2025-07-12)

### Feat

- Test imports upgraded to the new structure

### Fix

- Version

## 0.7.0 (2025-07-12)

### Feat

- Custom system prompt

### Fix

- GitHub release script now filters semantic version tags only
- Github release workflow

## 0.6.0 (2025-05-29)

### Feat

- Argentic as module
- Environment knowledge tool
- Environment store for coordinate-based RAG

### Fix

- reset version to baseline for proper commitizen operation
- Agent shutdown
- CLI client id
- Entry command arguments parsing
- Precommit testing scripts

## 0.5.0 (2025-05-16)
